@@ -19,7 +19,7 @@ from __future__ import annotations
 import os
 import traceback
 from contextlib import ExitStack
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, Literal
 
 import yaml
 from openlineage.client import OpenLineageClient, set_producer
@@ -32,7 +32,7 @@ from openlineage.client.facet_v2 import (
     job_type_job,
     nominal_time_run,
     ownership_job,
-    source_code_location_job,
+    tags_job,
 )
 from openlineage.client.uuid import generate_static_uuid
 
@@ -63,11 +63,8 @@ _PRODUCER = f"https://github.com/apache/airflow/tree/providers-openlineage/{OPEN
 
 set_producer(_PRODUCER)
 
-# https://openlineage.io/docs/spec/facets/job-facets/job-type
-# They must be set after the `set_producer(_PRODUCER)`
-# otherwise the `JobTypeJobFacet._producer` will be set with the default value
-_JOB_TYPE_DAG = job_type_job.JobTypeJobFacet(jobType="DAG", integration="AIRFLOW", processingType="BATCH")
-_JOB_TYPE_TASK = job_type_job.JobTypeJobFacet(jobType="TASK", integration="AIRFLOW", processingType="BATCH")
+_JOB_TYPE_DAG: Literal["DAG"] = "DAG"
+_JOB_TYPE_TASK: Literal["TASK"] = "TASK"
 
 
 class OpenLineageAdapter(LoggingMixin):
@@ -187,10 +184,10 @@ class OpenLineageAdapter(LoggingMixin):
         job_name: str,
         job_description: str,
         event_time: str,
-        code_location: str | None,
         nominal_start_time: str | None,
         nominal_end_time: str | None,
-        owners: list[str],
+        owners: list[str] | None,
+        tags: list[str] | None,
         task: OperatorLineage | None,
         run_facets: dict[str, RunFacet] | None = None,
     ) -> RunEvent:
@@ -201,17 +198,16 @@ class OpenLineageAdapter(LoggingMixin):
         :param job_name: globally unique identifier of task in dag
         :param job_description: user provided description of job
         :param event_time:
-        :param code_location: file path or URL of DAG file
         :param nominal_start_time: scheduled time of dag run
         :param nominal_end_time: following schedule of dag run
-        :param owners: list of owners of DAG
+        :param owners: list of owners
+        :param tags: list of tags
         :param task: metadata container with information extracted from operator
         :param run_facets: custom run facets
         """
         run_facets = run_facets or {}
         if task:
             run_facets = {**task.run_facets, **run_facets}
-        run_facets = {**run_facets, **get_processing_engine_facet()}  # type: ignore
         event = RunEvent(
             eventType=RunState.START,
             eventTime=event_time,
@@ -225,8 +221,8 @@ class OpenLineageAdapter(LoggingMixin):
                 job_name=job_name,
                 job_type=_JOB_TYPE_TASK,
                 job_description=job_description,
-                code_location=code_location,
-                owners=owners,
+                job_owners=owners,
+                job_tags=tags,
                 job_facets=task.job_facets if task else None,
             ),
             inputs=task.inputs if task else [],
@@ -241,6 +237,10 @@ class OpenLineageAdapter(LoggingMixin):
         job_name: str,
         end_time: str,
         task: OperatorLineage,
+        nominal_start_time: str | None,
+        nominal_end_time: str | None,
+        owners: list[str] | None,
+        tags: list[str] | None,
         run_facets: dict[str, RunFacet] | None = None,
     ) -> RunEvent:
         """
@@ -249,21 +249,32 @@ class OpenLineageAdapter(LoggingMixin):
         :param run_id: globally unique identifier of task in dag run
         :param job_name: globally unique identifier of task between dags
         :param end_time: time of task completion
+        :param tags: list of tags
+        :param nominal_start_time: scheduled time of dag run
+        :param nominal_end_time: following schedule of dag run
         :param task: metadata container with information extracted from operator
+        :param owners: list of owners
         :param run_facets: additional run facets
         """
         run_facets = run_facets or {}
         if task:
             run_facets = {**task.run_facets, **run_facets}
-        run_facets = {**run_facets, **get_processing_engine_facet()}  # type: ignore
         event = RunEvent(
             eventType=RunState.COMPLETE,
             eventTime=end_time,
             run=self._build_run(
                 run_id=run_id,
+                nominal_start_time=nominal_start_time,
+                nominal_end_time=nominal_end_time,
                 run_facets=run_facets,
             ),
-            job=self._build_job(job_name, job_type=_JOB_TYPE_TASK, job_facets=task.job_facets),
+            job=self._build_job(
+                job_name,
+                job_type=_JOB_TYPE_TASK,
+                job_facets=task.job_facets,
+                job_owners=owners,
+                job_tags=tags,
+            ),
             inputs=task.inputs,
             outputs=task.outputs,
             producer=_PRODUCER,
@@ -276,6 +287,10 @@ class OpenLineageAdapter(LoggingMixin):
         job_name: str,
         end_time: str,
         task: OperatorLineage,
+        nominal_start_time: str | None,
+        nominal_end_time: str | None,
+        owners: list[str] | None,
+        tags: list[str] | None,
         error: str | BaseException | None = None,
         run_facets: dict[str, RunFacet] | None = None,
     ) -> RunEvent:
@@ -287,13 +302,16 @@ class OpenLineageAdapter(LoggingMixin):
         :param end_time: time of task completion
         :param task: metadata container with information extracted from operator
         :param run_facets: custom run facets
+        :param tags: list of tags
+        :param nominal_start_time: scheduled time of dag run
+        :param nominal_end_time: following schedule of dag run
+        :param owners: list of owners
         :param error: error
         :param run_facets: additional run facets
         """
         run_facets = run_facets or {}
         if task:
             run_facets = {**task.run_facets, **run_facets}
-        run_facets = {**run_facets, **get_processing_engine_facet()}  # type: ignore
 
         if error:
             stack_trace = None
@@ -310,9 +328,17 @@ class OpenLineageAdapter(LoggingMixin):
             eventTime=end_time,
             run=self._build_run(
                 run_id=run_id,
+                nominal_start_time=nominal_start_time,
+                nominal_end_time=nominal_end_time,
                 run_facets=run_facets,
             ),
-            job=self._build_job(job_name, job_type=_JOB_TYPE_TASK, job_facets=task.job_facets),
+            job=self._build_job(
+                job_name,
+                job_type=_JOB_TYPE_TASK,
+                job_facets=task.job_facets,
+                job_owners=owners,
+                job_tags=tags,
+            ),
             inputs=task.inputs,
             outputs=task.outputs,
             producer=_PRODUCER,
@@ -324,9 +350,10 @@ class OpenLineageAdapter(LoggingMixin):
         dag_id: str,
         logical_date: datetime,
         start_date: datetime,
-        nominal_start_time: str,
-        nominal_end_time: str,
-        owners: list[str],
+        nominal_start_time: str | None,
+        nominal_end_time: str | None,
+        owners: list[str] | None,
+        tags: list[str],
         run_facets: dict[str, RunFacet],
         clear_number: int,
         description: str | None = None,
@@ -340,8 +367,9 @@ class OpenLineageAdapter(LoggingMixin):
                     job_name=dag_id,
                     job_type=_JOB_TYPE_DAG,
                     job_description=description,
-                    owners=owners,
+                    job_owners=owners,
                     job_facets=job_facets,
+                    job_tags=tags,
                 ),
                 run=self._build_run(
                     run_id=self.build_dag_run_id(
@@ -349,7 +377,7 @@ class OpenLineageAdapter(LoggingMixin):
                     ),
                     nominal_start_time=nominal_start_time,
                     nominal_end_time=nominal_end_time,
-                    run_facets={**run_facets, **get_airflow_debug_facet(), **get_processing_engine_facet()},
+                    run_facets={**run_facets, **get_airflow_debug_facet()},
                 ),
                 inputs=[],
                 outputs=[],
@@ -368,24 +396,34 @@ class OpenLineageAdapter(LoggingMixin):
         run_id: str,
         end_date: datetime,
         logical_date: datetime,
+        nominal_start_time: str | None,
+        nominal_end_time: str | None,
+        tags: list[str] | None,
         clear_number: int,
         dag_run_state: DagRunState,
         task_ids: list[str],
+        owners: list[str] | None,
         run_facets: dict[str, RunFacet],
     ):
         try:
             event = RunEvent(
                 eventType=RunState.COMPLETE,
                 eventTime=end_date.isoformat(),
-                job=self._build_job(job_name=dag_id, job_type=_JOB_TYPE_DAG),
-                run=Run(
-                    runId=self.build_dag_run_id(
+                job=self._build_job(
+                    job_name=dag_id,
+                    job_type=_JOB_TYPE_DAG,
+                    job_owners=owners,
+                    job_tags=tags,
+                ),
+                run=self._build_run(
+                    run_id=self.build_dag_run_id(
                         dag_id=dag_id, logical_date=logical_date, clear_number=clear_number
                     ),
-                    facets={
+                    nominal_start_time=nominal_start_time,
+                    nominal_end_time=nominal_end_time,
+                    run_facets={
                         **get_airflow_state_run_facet(dag_id, run_id, task_ids, dag_run_state),
                         **get_airflow_debug_facet(),
-                        **get_processing_engine_facet(),
                         **run_facets,
                     },
                 ),
@@ -406,9 +444,13 @@ class OpenLineageAdapter(LoggingMixin):
         run_id: str,
         end_date: datetime,
         logical_date: datetime,
+        nominal_start_time: str | None,
+        nominal_end_time: str | None,
+        tags: list[str] | None,
         clear_number: int,
         dag_run_state: DagRunState,
         task_ids: list[str],
+        owners: list[str] | None,
         msg: str,
         run_facets: dict[str, RunFacet],
     ):
@@ -416,20 +458,24 @@ class OpenLineageAdapter(LoggingMixin):
             event = RunEvent(
                 eventType=RunState.FAIL,
                 eventTime=end_date.isoformat(),
-                job=self._build_job(job_name=dag_id, job_type=_JOB_TYPE_DAG),
-                run=Run(
-                    runId=self.build_dag_run_id(
-                        dag_id=dag_id,
-                        logical_date=logical_date,
-                        clear_number=clear_number,
+                job=self._build_job(
+                    job_name=dag_id,
+                    job_type=_JOB_TYPE_DAG,
+                    job_owners=owners,
+                    job_tags=tags,
+                ),
+                run=self._build_run(
+                    run_id=self.build_dag_run_id(
+                        dag_id=dag_id, logical_date=logical_date, clear_number=clear_number
                     ),
-                    facets={
+                    nominal_start_time=nominal_start_time,
+                    nominal_end_time=nominal_end_time,
+                    run_facets={
                         "errorMessage": error_message_run.ErrorMessageRunFacet(
                             message=msg, programmingLanguage="python"
                         ),
                         **get_airflow_state_run_facet(dag_id, run_id, task_ids, dag_run_state),
                         **get_airflow_debug_facet(),
-                        **get_processing_engine_facet(),
                         **run_facets,
                     },
                 ),
@@ -452,49 +498,73 @@ class OpenLineageAdapter(LoggingMixin):
         run_facets: dict[str, RunFacet] | None = None,
     ) -> Run:
         facets: dict[str, RunFacet] = {}
-        if nominal_start_time:
-            facets.update(
-                {"nominalTime": nominal_time_run.NominalTimeRunFacet(nominal_start_time, nominal_end_time)}
-            )
         if run_facets:
             facets.update(run_facets)
+        if nominal_start_time:
+            facets.update(
+                {
+                    "nominalTime": nominal_time_run.NominalTimeRunFacet(
+                        nominalStartTime=nominal_start_time,
+                        nominalEndTime=nominal_end_time,
+                        producer=_PRODUCER,
+                    )
+                }
+            )
+        facets.update(get_processing_engine_facet())
 
         return Run(run_id, facets)
 
     @staticmethod
     def _build_job(
         job_name: str,
-        job_type: job_type_job.JobTypeJobFacet,
+        job_type: Literal["DAG", "TASK"],
         job_description: str | None = None,
-        code_location: str | None = None,
-        owners: list[str] | None = None,
+        job_owners: list[str] | None = None,
+        job_tags: list[str] | None = None,
         job_facets: dict[str, JobFacet] | None = None,
     ):
         facets: dict[str, JobFacet] = {}
-
+        if job_facets:
+            facets.update(job_facets)
         if job_description:
-            facets.update(
-                {"documentation": documentation_job.DocumentationJobFacet(description=job_description)}
-            )
-        if code_location:
             facets.update(
                 {
-                    "sourceCodeLocation": source_code_location_job.SourceCodeLocationJobFacet(
-                        "", url=code_location
+                    "documentation": documentation_job.DocumentationJobFacet(
+                        description=job_description, producer=_PRODUCER
                     )
                 }
             )
-        if owners:
+        if job_owners:
             facets.update(
                 {
                     "ownership": ownership_job.OwnershipJobFacet(
-                        owners=[ownership_job.Owner(name=owner) for owner in owners]
+                        owners=[ownership_job.Owner(name=owner) for owner in sorted(job_owners)],
+                        producer=_PRODUCER,
                     )
                 }
             )
-        if job_facets:
-            facets = {**facets, **job_facets}
+        if job_tags:
+            facets.update(
+                {
+                    "tags": tags_job.TagsJobFacet(
+                        tags=[
+                            tags_job.TagsJobFacetFields(
+                                key=tag,
+                                value=tag,
+                                source="AIRFLOW",
+                            )
+                            for tag in sorted(job_tags)
+                        ],
+                        producer=_PRODUCER,
+                    )
+                }
+            )
+        facets.update(
+            {
+                "jobType": job_type_job.JobTypeJobFacet(
+                    jobType=job_type, integration="AIRFLOW", processingType="BATCH", producer=_PRODUCER
+                )
+            }
+        )
 
-        facets.update({"jobType": job_type})
-
-        return Job(conf.namespace(), job_name, facets)
+        return Job(namespace=conf.namespace(), name=job_name, facets=facets)
