@@ -18,9 +18,10 @@ from __future__ import annotations
 
 import uuid
 from collections import defaultdict
+from collections.abc import Callable
 from concurrent.futures import Future
 from contextlib import suppress
-from typing import TYPE_CHECKING, Callable
+from typing import TYPE_CHECKING
 from unittest import mock
 from unittest.mock import MagicMock, patch
 
@@ -32,7 +33,14 @@ from openlineage.client.transport.console import ConsoleConfig
 from uuid6 import uuid7
 
 from airflow.models import DAG, DagRun, TaskInstance
-from airflow.models.baseoperator import BaseOperator
+
+from tests_common.test_utils.version_compat import AIRFLOW_V_3_0_PLUS
+
+if AIRFLOW_V_3_0_PLUS:
+    from airflow.sdk import BaseOperator
+else:
+    from airflow.models.baseoperator import BaseOperator  # type: ignore[no-redef]
+
 from airflow.providers.openlineage.extractors.base import OperatorLineage
 from airflow.providers.openlineage.plugins.adapter import OpenLineageAdapter
 from airflow.providers.openlineage.plugins.listener import OpenLineageListener
@@ -45,8 +53,6 @@ from tests_common.test_utils.config import conf_vars
 from tests_common.test_utils.db import clear_db_runs
 from tests_common.test_utils.version_compat import AIRFLOW_V_3_0_PLUS
 
-pytestmark = pytest.mark.db_test
-
 EXPECTED_TRY_NUMBER_1 = 1
 
 TRY_NUMBER_BEFORE_EXECUTION = 0
@@ -244,7 +250,7 @@ class TestOpenLineageListenerAirflow2:
         task_instance.dag_run.clear_number = 0
         task_instance.dag_run.execution_date = timezone.datetime(2020, 1, 1, 1, 1, 1)
         task_instance.task = mock.Mock()
-        task_instance.task.task_id = "task_id"
+        task_instance.task.task_id = "task_id_from_task_and_not_ti"
         task_instance.task.dag = mock.Mock()
         task_instance.task.dag.dag_id = "dag_id"
         task_instance.task.dag.description = "Test DAG Description"
@@ -255,6 +261,7 @@ class TestOpenLineageListenerAirflow2:
         task_instance.task.outlets = []
         task_instance.dag_id = "dag_id"
         task_instance.run_id = "dag_run_run_id"
+        task_instance.task_id = "task_id"
         task_instance.try_number = 1
         task_instance.state = State.RUNNING
         task_instance.start_date = timezone.datetime(2023, 1, 1, 13, 1, 1)
@@ -275,13 +282,11 @@ class TestOpenLineageListenerAirflow2:
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_run_facet")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_mapped_task_facet")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_user_provided_run_facets")
-    @mock.patch("airflow.providers.openlineage.plugins.listener.get_job_name")
     @mock.patch(
         "airflow.providers.openlineage.plugins.listener.OpenLineageListener._execute", new=regular_call
     )
     def test_adapter_start_task_is_called_with_proper_arguments(
         self,
-        mock_get_job_name,
         mock_get_airflow_mapped_task_facet,
         mock_get_user_provided_run_facets,
         mock_get_airflow_run_facet,
@@ -299,7 +304,6 @@ class TestOpenLineageListenerAirflow2:
         reflecting the comprehensive tracking of task execution contexts."""
 
         listener, task_instance = self._create_listener_and_task_instance()
-        mock_get_job_name.return_value = "job_name"
         mock_get_airflow_mapped_task_facet.return_value = {"mapped_facet": 1}
         mock_get_user_provided_run_facets.return_value = {"custom_user_facet": 2}
         mock_get_airflow_run_facet.return_value = {"airflow_run_facet": 3}
@@ -310,7 +314,7 @@ class TestOpenLineageListenerAirflow2:
         listener.on_task_instance_running(None, task_instance, None)
         listener.adapter.start_task.assert_called_once_with(
             run_id="2020-01-01T01:01:01+00:00.dag_id.task_id.1.-1",
-            job_name="job_name",
+            job_name="dag_id.task_id",
             job_description="Test DAG Description",
             event_time="2023-01-01T13:01:01+00:00",
             nominal_start_time=None,
@@ -334,13 +338,11 @@ class TestOpenLineageListenerAirflow2:
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_run_facet")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_mapped_task_facet")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_user_provided_run_facets")
-    @mock.patch("airflow.providers.openlineage.plugins.listener.get_job_name")
     @mock.patch(
         "airflow.providers.openlineage.plugins.listener.OpenLineageListener._execute", new=regular_call
     )
     def test_adapter_start_task_is_called_with_dag_owners_when_task_owner_is_default(
         self,
-        mock_get_job_name,
         mock_get_airflow_mapped_task_facet,
         mock_get_user_provided_run_facets,
         mock_get_airflow_run_facet,
@@ -350,7 +352,6 @@ class TestOpenLineageListenerAirflow2:
         mock_debug_mode,
     ):
         listener, task_instance = self._create_listener_and_task_instance()
-        mock_get_job_name.return_value = "job_name"
         mock_get_airflow_mapped_task_facet.return_value = {"mapped_facet": 1}
         mock_get_user_provided_run_facets.return_value = {"custom_user_facet": 2}
         mock_get_airflow_run_facet.return_value = {"airflow_run_facet": 3}
@@ -368,7 +369,6 @@ class TestOpenLineageListenerAirflow2:
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_task_parent_run_facet")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_run_facet")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_user_provided_run_facets")
-    @mock.patch("airflow.providers.openlineage.plugins.listener.get_job_name")
     @mock.patch(
         "airflow.providers.openlineage.plugins.listener.OpenLineageListener._execute", new=regular_call
     )
@@ -376,7 +376,6 @@ class TestOpenLineageListenerAirflow2:
     def test_adapter_fail_task_is_called_with_proper_arguments(
         self,
         mock_utcnow,
-        mock_get_job_name,
         mock_get_user_provided_run_facets,
         mock_get_airflow_run_facet,
         mock_get_task_parent_run_facet,
@@ -394,7 +393,6 @@ class TestOpenLineageListenerAirflow2:
 
         listener, task_instance = self._create_listener_and_task_instance()
         task_instance.logical_date = timezone.datetime(2020, 1, 1, 1, 1, 1)
-        mock_get_job_name.return_value = "job_name"
         mock_get_user_provided_run_facets.return_value = {"custom_user_facet": 2}
         mock_get_airflow_run_facet.return_value = {"airflow": {"task": "..."}}
         mock_get_task_parent_run_facet.return_value = {"parent": 4}
@@ -407,7 +405,7 @@ class TestOpenLineageListenerAirflow2:
         )
         listener.adapter.fail_task.assert_called_once_with(
             end_time="2023-01-03T13:01:01+00:00",
-            job_name="job_name",
+            job_name="dag_id.task_id",
             run_id="2020-01-01T01:01:01+00:00.dag_id.task_id.1.-1",
             owners=["task_owner"],
             tags=["tag1", "tag2"],
@@ -430,13 +428,11 @@ class TestOpenLineageListenerAirflow2:
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_run_facet")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_mapped_task_facet")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_user_provided_run_facets")
-    @mock.patch("airflow.providers.openlineage.plugins.listener.get_job_name")
     @mock.patch(
         "airflow.providers.openlineage.plugins.listener.OpenLineageListener._execute", new=regular_call
     )
     def test_adapter_fail_task_is_called_with_dag_owners_when_task_owner_is_default(
         self,
-        mock_get_job_name,
         mock_get_airflow_mapped_task_facet,
         mock_get_user_provided_run_facets,
         mock_get_airflow_run_facet,
@@ -446,7 +442,6 @@ class TestOpenLineageListenerAirflow2:
         mock_debug_mode,
     ):
         listener, task_instance = self._create_listener_and_task_instance()
-        mock_get_job_name.return_value = "job_name"
         mock_get_airflow_mapped_task_facet.return_value = {"mapped_facet": 1}
         mock_get_user_provided_run_facets.return_value = {"custom_user_facet": 2}
         mock_get_airflow_run_facet.return_value = {"airflow_run_facet": 3}
@@ -467,7 +462,6 @@ class TestOpenLineageListenerAirflow2:
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_task_parent_run_facet")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_run_facet")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_user_provided_run_facets")
-    @mock.patch("airflow.providers.openlineage.plugins.listener.get_job_name")
     @mock.patch(
         "airflow.providers.openlineage.plugins.listener.OpenLineageListener._execute", new=regular_call
     )
@@ -475,7 +469,6 @@ class TestOpenLineageListenerAirflow2:
     def test_adapter_complete_task_is_called_with_proper_arguments(
         self,
         mock_utcnow,
-        mock_get_job_name,
         mock_get_user_provided_run_facets,
         mock_get_airflow_run_facet,
         mock_get_task_parent_run_facet,
@@ -493,7 +486,6 @@ class TestOpenLineageListenerAirflow2:
         """
 
         listener, task_instance = self._create_listener_and_task_instance()
-        mock_get_job_name.return_value = "job_name"
         mock_get_user_provided_run_facets.return_value = {"custom_user_facet": 2}
         mock_get_airflow_run_facet.return_value = {"airflow": {"task": "..."}}
         mock_get_task_parent_run_facet.return_value = {"parent": 4}
@@ -507,7 +499,7 @@ class TestOpenLineageListenerAirflow2:
         assert len(calls) == 1
         assert calls[0][1] == dict(
             end_time="2023-01-03T13:01:01+00:00",
-            job_name="job_name",
+            job_name="dag_id.task_id",
             run_id=f"2020-01-01T01:01:01+00:00.dag_id.task_id.{EXPECTED_TRY_NUMBER_1}.-1",
             task=listener.extractor_manager.extract_metadata(),
             owners=["task_owner"],
@@ -529,13 +521,11 @@ class TestOpenLineageListenerAirflow2:
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_run_facet")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_mapped_task_facet")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_user_provided_run_facets")
-    @mock.patch("airflow.providers.openlineage.plugins.listener.get_job_name")
     @mock.patch(
         "airflow.providers.openlineage.plugins.listener.OpenLineageListener._execute", new=regular_call
     )
     def test_adapter_complete_task_is_called_with_dag_owners_when_task_owner_is_default(
         self,
-        mock_get_job_name,
         mock_get_airflow_mapped_task_facet,
         mock_get_user_provided_run_facets,
         mock_get_airflow_run_facet,
@@ -545,7 +535,6 @@ class TestOpenLineageListenerAirflow2:
         mock_debug_mode,
     ):
         listener, task_instance = self._create_listener_and_task_instance()
-        mock_get_job_name.return_value = "job_name"
         mock_get_airflow_mapped_task_facet.return_value = {"mapped_facet": 1}
         mock_get_user_provided_run_facets.return_value = {"custom_user_facet": 2}
         mock_get_airflow_run_facet.return_value = {"airflow_run_facet": 3}
@@ -683,12 +672,10 @@ class TestOpenLineageListenerAirflow2:
     @mock.patch("airflow.providers.openlineage.plugins.listener.is_operator_disabled")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_run_facet")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_user_provided_run_facets")
-    @mock.patch("airflow.providers.openlineage.plugins.listener.get_job_name")
     def test_listener_on_task_instance_running_do_not_call_adapter_when_disabled_operator(
-        self, mock_get_job_name, mock_get_user_provided_run_facets, mock_get_airflow_run_facet, mock_disabled
+        self, mock_get_user_provided_run_facets, mock_get_airflow_run_facet, mock_disabled
     ):
         listener, task_instance = self._create_listener_and_task_instance()
-        mock_get_job_name.return_value = "job_name"
         mock_get_user_provided_run_facets.return_value = {"custom_facet": 2}
         mock_get_airflow_run_facet.return_value = {"airflow_run_facet": 3}
         mock_disabled.return_value = True
@@ -702,9 +689,8 @@ class TestOpenLineageListenerAirflow2:
 
     @mock.patch("airflow.providers.openlineage.plugins.listener.is_operator_disabled")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_user_provided_run_facets")
-    @mock.patch("airflow.providers.openlineage.plugins.listener.get_job_name")
     def test_listener_on_task_instance_failed_do_not_call_adapter_when_disabled_operator(
-        self, mock_get_job_name, mock_get_user_provided_run_facets, mock_disabled
+        self, mock_get_user_provided_run_facets, mock_disabled
     ):
         listener, task_instance = self._create_listener_and_task_instance()
         mock_get_user_provided_run_facets.return_value = {"custom_facet": 2}
@@ -723,9 +709,8 @@ class TestOpenLineageListenerAirflow2:
 
     @mock.patch("airflow.providers.openlineage.plugins.listener.is_operator_disabled")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_user_provided_run_facets")
-    @mock.patch("airflow.providers.openlineage.plugins.listener.get_job_name")
     def test_listener_on_task_instance_success_do_not_call_adapter_when_disabled_operator(
-        self, mock_get_job_name, mock_get_user_provided_run_facets, mock_disabled
+        self, mock_get_user_provided_run_facets, mock_disabled
     ):
         listener, task_instance = self._create_listener_and_task_instance()
         mock_get_user_provided_run_facets.return_value = {"custom_facet": 2}
@@ -757,6 +742,7 @@ class TestOpenLineageListenerAirflow2:
         mock_executor.assert_called_once_with(max_workers=expected, initializer=mock.ANY)
         mock_executor.return_value.submit.assert_called_once()
 
+    @pytest.mark.db_test
     @pytest.mark.parametrize(
         ("method", "dag_run_state"),
         [
@@ -968,7 +954,7 @@ class TestOpenLineageListenerAirflow3:
             # TaskInstance is used when on API server (when listener gets called about manual state change)
             task_instance = TaskInstance(task=MagicMock())  # type: ignore
             task_instance.dag_run = DagRun()
-            task_instance.dag_run.dag_id = "dag_id"
+            task_instance.dag_run.dag_id = "dag_id_from_dagrun_and_not_ti"
             task_instance.dag_run.run_id = "dag_run_run_id"
             task_instance.dag_run.clear_number = 0
             task_instance.dag_run.logical_date = timezone.datetime(2020, 1, 1, 1, 1, 1)
@@ -976,6 +962,7 @@ class TestOpenLineageListenerAirflow3:
             task_instance.task = None
             task_instance.dag = None
             task_instance.task_id = "task_id"
+            task_instance.dag_id = "dag_id"
             task_instance.try_number = 1
             task_instance.map_index = -1
         else:
@@ -990,12 +977,12 @@ class TestOpenLineageListenerAirflow3:
             from airflow.sdk.execution_time.task_runner import RuntimeTaskInstance
 
             dag = DAG(
-                dag_id="dag_id",
+                dag_id="dag_id_from_dag_not_ti",
                 description="Test DAG Description",
                 tags=["tag1", "tag2"],
             )
-            task = EmptyOperator(task_id="task_id", dag=dag, owner="task_owner")
-            task2 = EmptyOperator(task_id="task_id2", dag=dag, owner="another_owner")  # noqa: F841
+            task = EmptyOperator(task_id="task_id_from_task_not_ti", dag=dag, owner="task_owner")
+            task2 = EmptyOperator(task_id="task_id2_from_task_not_ti", dag=dag, owner="another_owner")  # noqa: F841
 
             sdk_task_instance = SdkTaskInstance(
                 id=uuid7(),
@@ -1010,8 +997,8 @@ class TestOpenLineageListenerAirflow3:
                 task=task,
                 _ti_context_from_server=TIRunContext(
                     dag_run=SdkDagRun(
-                        dag_id="dag_id",
-                        run_id="dag_run_run_id",
+                        dag_id="dag_id_from_dagrun_not_ti",
+                        run_id="dag_run_run_id_from_dagrun_not_ti",
                         logical_date=timezone.datetime(2020, 1, 1, 1, 1, 1),
                         data_interval_start=None,
                         data_interval_end=None,
@@ -1060,13 +1047,11 @@ class TestOpenLineageListenerAirflow3:
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_run_facet")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_mapped_task_facet")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_user_provided_run_facets")
-    @mock.patch("airflow.providers.openlineage.plugins.listener.get_job_name")
     @mock.patch(
         "airflow.providers.openlineage.plugins.listener.OpenLineageListener._execute", new=regular_call
     )
     def test_adapter_start_task_is_called_with_proper_arguments(
         self,
-        mock_get_job_name,
         mock_get_airflow_mapped_task_facet,
         mock_get_user_provided_run_facets,
         mock_get_airflow_run_facet,
@@ -1084,7 +1069,7 @@ class TestOpenLineageListenerAirflow3:
         reflecting the comprehensive tracking of task execution contexts."""
 
         listener, task_instance = self._create_listener_and_task_instance()
-        mock_get_job_name.return_value = "job_name"
+
         mock_get_airflow_mapped_task_facet.return_value = {"mapped_facet": 1}
         mock_get_user_provided_run_facets.return_value = {"custom_user_facet": 2}
         mock_get_airflow_run_facet.return_value = {"airflow_run_facet": 3}
@@ -1095,7 +1080,7 @@ class TestOpenLineageListenerAirflow3:
         listener.on_task_instance_running(None, task_instance)
         listener.adapter.start_task.assert_called_once_with(
             run_id="2020-01-01T01:01:01+00:00.dag_id.task_id.1.-1",
-            job_name="job_name",
+            job_name="dag_id.task_id",
             job_description="Test DAG Description",
             event_time="2023-01-01T13:01:01+00:00",
             nominal_start_time=None,
@@ -1119,13 +1104,11 @@ class TestOpenLineageListenerAirflow3:
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_run_facet")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_mapped_task_facet")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_user_provided_run_facets")
-    @mock.patch("airflow.providers.openlineage.plugins.listener.get_job_name")
     @mock.patch(
         "airflow.providers.openlineage.plugins.listener.OpenLineageListener._execute", new=regular_call
     )
     def test_adapter_start_task_is_called_with_dag_owners_when_task_owner_is_default(
         self,
-        mock_get_job_name,
         mock_get_airflow_mapped_task_facet,
         mock_get_user_provided_run_facets,
         mock_get_airflow_run_facet,
@@ -1135,7 +1118,6 @@ class TestOpenLineageListenerAirflow3:
         mock_debug_mode,
     ):
         listener, task_instance = self._create_listener_and_task_instance()
-        mock_get_job_name.return_value = "job_name"
         mock_get_airflow_mapped_task_facet.return_value = {"mapped_facet": 1}
         mock_get_user_provided_run_facets.return_value = {"custom_user_facet": 2}
         mock_get_airflow_run_facet.return_value = {"airflow_run_facet": 3}
@@ -1154,7 +1136,6 @@ class TestOpenLineageListenerAirflow3:
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_task_parent_run_facet")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_run_facet")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_user_provided_run_facets")
-    @mock.patch("airflow.providers.openlineage.plugins.listener.get_job_name")
     @mock.patch(
         "airflow.providers.openlineage.plugins.listener.OpenLineageListener._execute", new=regular_call
     )
@@ -1162,7 +1143,6 @@ class TestOpenLineageListenerAirflow3:
     def test_adapter_fail_task_is_called_with_proper_arguments(
         self,
         mock_utcnow,
-        mock_get_job_name,
         mock_get_user_provided_run_facets,
         mock_get_airflow_run_facet,
         mock_get_task_parent_run_facet,
@@ -1180,7 +1160,6 @@ class TestOpenLineageListenerAirflow3:
 
         listener, task_instance = self._create_listener_and_task_instance()
         task_instance.get_template_context()["dag_run"].logical_date = timezone.datetime(2020, 1, 1, 1, 1, 1)
-        mock_get_job_name.return_value = "job_name"
         mock_get_user_provided_run_facets.return_value = {"custom_user_facet": 2}
         mock_get_airflow_run_facet.return_value = {"airflow": {"task": "..."}}
         mock_get_task_parent_run_facet.return_value = {"parent": 4}
@@ -1191,7 +1170,7 @@ class TestOpenLineageListenerAirflow3:
         listener.on_task_instance_failed(previous_state=None, task_instance=task_instance, error=err)
         listener.adapter.fail_task.assert_called_once_with(
             end_time="2023-01-03T13:01:01+00:00",
-            job_name="job_name",
+            job_name="dag_id.task_id",
             run_id="2020-01-01T01:01:01+00:00.dag_id.task_id.1.-1",
             task=listener.extractor_manager.extract_metadata(),
             owners=["task_owner"],
@@ -1214,13 +1193,11 @@ class TestOpenLineageListenerAirflow3:
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_run_facet")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_mapped_task_facet")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_user_provided_run_facets")
-    @mock.patch("airflow.providers.openlineage.plugins.listener.get_job_name")
     @mock.patch(
         "airflow.providers.openlineage.plugins.listener.OpenLineageListener._execute", new=regular_call
     )
     def test_adapter_fail_task_is_called_with_dag_owners_when_task_owner_is_default(
         self,
-        mock_get_job_name,
         mock_get_airflow_mapped_task_facet,
         mock_get_user_provided_run_facets,
         mock_get_airflow_run_facet,
@@ -1230,7 +1207,6 @@ class TestOpenLineageListenerAirflow3:
         mock_debug_mode,
     ):
         listener, task_instance = self._create_listener_and_task_instance()
-        mock_get_job_name.return_value = "job_name"
         mock_get_airflow_mapped_task_facet.return_value = {"mapped_facet": 1}
         mock_get_user_provided_run_facets.return_value = {"custom_user_facet": 2}
         mock_get_airflow_run_facet.return_value = {"airflow_run_facet": 3}
@@ -1245,10 +1221,10 @@ class TestOpenLineageListenerAirflow3:
         call_owners = listener.adapter.fail_task.call_args.kwargs["owners"]
         assert sorted(call_owners) == ["airflow", "another_owner"]
 
+    @mock.patch("airflow.providers.openlineage.plugins.adapter.OpenLineageAdapter.emit")
     @mock.patch("airflow.providers.openlineage.conf.debug_mode", return_value=True)
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_debug_facet")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_task_parent_run_facet")
-    @mock.patch("airflow.providers.openlineage.plugins.listener.get_job_name")
     @mock.patch(
         "airflow.providers.openlineage.plugins.listener.OpenLineageListener._execute", new=regular_call
     )
@@ -1256,10 +1232,10 @@ class TestOpenLineageListenerAirflow3:
     def test_adapter_fail_task_is_called_with_proper_arguments_for_db_task_instance_model(
         self,
         mock_utcnow,
-        mock_get_job_name,
         mock_get_task_parent_run_facet,
         mock_debug_facet,
         mock_debug_mode,
+        mock_emit,
     ):
         """Tests that the 'fail_task' method of the OpenLineageAdapter is invoked with the correct arguments.
 
@@ -1268,31 +1244,36 @@ class TestOpenLineageListenerAirflow3:
         """
 
         listener, task_instance = self._create_listener_and_task_instance(runtime_ti=False)
-        mock_get_job_name.return_value = "job_name"
         mock_get_task_parent_run_facet.return_value = {"parent": 4}
         mock_debug_facet.return_value = {"debug": "packages"}
 
         err = ValueError("test")
-        on_task_failed_listener_kwargs = {"error": err}
-        expected_err_kwargs = {"error": err}
 
-        listener.on_task_instance_failed(
-            previous_state=None, task_instance=task_instance, **on_task_failed_listener_kwargs
-        )
+        listener.on_task_instance_failed(previous_state=None, task_instance=task_instance, error=err)
         mock_get_task_parent_run_facet.assert_called_once_with(
             parent_run_id="2020-01-01T01:01:01+00:00.dag_id.0", parent_job_name=task_instance.dag_id
         )
-        listener.adapter.fail_task.assert_called_once_with(
+        expected_args = dict(
             end_time="2023-01-03T13:01:01+00:00",
-            job_name="job_name",
+            job_name="dag_id.task_id",
             run_id="2020-01-01T01:01:01+00:00.dag_id.task_id.1.-1",
             task=OperatorLineage(),
+            nominal_start_time=None,
+            nominal_end_time=None,
+            tags=None,
+            owners=None,
             run_facets={
                 "parent": 4,
                 "debug": "packages",
             },
-            **expected_err_kwargs,
+            error=err,
         )
+        listener.adapter.fail_task.assert_called_once_with(**expected_args)
+
+        expected_args["run_id"] = "9d3b14f7-de91-40b6-aeef-e887e2c7673e"
+        adapter = OpenLineageAdapter()
+        adapter.fail_task(**expected_args)
+        assert mock_emit.assert_called_once
 
     @mock.patch("airflow.providers.openlineage.conf.debug_mode", return_value=True)
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_debug_facet")
@@ -1300,7 +1281,6 @@ class TestOpenLineageListenerAirflow3:
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_task_parent_run_facet")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_run_facet")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_user_provided_run_facets")
-    @mock.patch("airflow.providers.openlineage.plugins.listener.get_job_name")
     @mock.patch(
         "airflow.providers.openlineage.plugins.listener.OpenLineageListener._execute", new=regular_call
     )
@@ -1308,7 +1288,6 @@ class TestOpenLineageListenerAirflow3:
     def test_adapter_complete_task_is_called_with_proper_arguments(
         self,
         mock_utcnow,
-        mock_get_job_name,
         mock_get_user_provided_run_facets,
         mock_get_airflow_run_facet,
         mock_get_task_parent_run_facet,
@@ -1326,7 +1305,6 @@ class TestOpenLineageListenerAirflow3:
         """
 
         listener, task_instance = self._create_listener_and_task_instance()
-        mock_get_job_name.return_value = "job_name"
         mock_get_user_provided_run_facets.return_value = {"custom_user_facet": 2}
         mock_get_airflow_run_facet.return_value = {"airflow": {"task": "..."}}
         mock_get_task_parent_run_facet.return_value = {"parent": 4}
@@ -1338,7 +1316,7 @@ class TestOpenLineageListenerAirflow3:
         assert len(calls) == 1
         assert calls[0][1] == dict(
             end_time="2023-01-03T13:01:01+00:00",
-            job_name="job_name",
+            job_name="dag_id.task_id",
             run_id="2020-01-01T01:01:01+00:00.dag_id.task_id.1.-1",
             task=listener.extractor_manager.extract_metadata(),
             owners=["task_owner"],
@@ -1360,13 +1338,11 @@ class TestOpenLineageListenerAirflow3:
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_run_facet")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_mapped_task_facet")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_user_provided_run_facets")
-    @mock.patch("airflow.providers.openlineage.plugins.listener.get_job_name")
     @mock.patch(
         "airflow.providers.openlineage.plugins.listener.OpenLineageListener._execute", new=regular_call
     )
     def test_adapter_complete_task_is_called_with_dag_owners_when_task_owner_is_default(
         self,
-        mock_get_job_name,
         mock_get_airflow_mapped_task_facet,
         mock_get_user_provided_run_facets,
         mock_get_airflow_run_facet,
@@ -1376,7 +1352,6 @@ class TestOpenLineageListenerAirflow3:
         mock_debug_mode,
     ):
         listener, task_instance = self._create_listener_and_task_instance()
-        mock_get_job_name.return_value = "job_name"
         mock_get_airflow_mapped_task_facet.return_value = {"mapped_facet": 1}
         mock_get_user_provided_run_facets.return_value = {"custom_user_facet": 2}
         mock_get_airflow_run_facet.return_value = {"airflow_run_facet": 3}
@@ -1390,21 +1365,16 @@ class TestOpenLineageListenerAirflow3:
         call_owners = listener.adapter.complete_task.call_args.kwargs["owners"]
         assert sorted(call_owners) == ["airflow", "another_owner"]
 
+    @mock.patch("airflow.providers.openlineage.plugins.adapter.OpenLineageAdapter.emit")
     @mock.patch("airflow.providers.openlineage.conf.debug_mode", return_value=True)
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_debug_facet")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_task_parent_run_facet")
-    @mock.patch("airflow.providers.openlineage.plugins.listener.get_job_name")
     @mock.patch(
         "airflow.providers.openlineage.plugins.listener.OpenLineageListener._execute", new=regular_call
     )
     @mock.patch("airflow.utils.timezone.utcnow", return_value=timezone.datetime(2023, 1, 3, 13, 1, 1))
     def test_adapter_complete_task_is_called_with_proper_arguments_for_db_task_instance_model(
-        self,
-        mock_utcnow,
-        mock_get_job_name,
-        mock_get_task_parent_run_facet,
-        mock_debug_facet,
-        mock_debug_mode,
+        self, mock_utcnow, mock_get_task_parent_run_facet, mock_debug_facet, mock_debug_mode, mock_emit
     ):
         """Tests that the 'complete_task' method of the OpenLineageAdapter is called with the correct arguments.
 
@@ -1412,7 +1382,6 @@ class TestOpenLineageListenerAirflow3:
         to simulate the listener being called after task's state has been manually set via API.
         """
         listener, task_instance = self._create_listener_and_task_instance(runtime_ti=False)
-        mock_get_job_name.return_value = "job_name"
         mock_get_task_parent_run_facet.return_value = {"parent": 4}
         mock_debug_facet.return_value = {"debug": "packages"}
 
@@ -1422,16 +1391,26 @@ class TestOpenLineageListenerAirflow3:
         mock_get_task_parent_run_facet.assert_called_once_with(
             parent_run_id="2020-01-01T01:01:01+00:00.dag_id.0", parent_job_name=task_instance.dag_id
         )
-        assert calls[0][1] == dict(
+        expected_args = dict(
             end_time="2023-01-03T13:01:01+00:00",
-            job_name="job_name",
+            job_name="dag_id.task_id",
             run_id="2020-01-01T01:01:01+00:00.dag_id.task_id.1.-1",
             task=OperatorLineage(),
+            nominal_start_time=None,
+            nominal_end_time=None,
+            tags=None,
+            owners=None,
             run_facets={
                 "parent": 4,
                 "debug": "packages",
             },
         )
+        assert calls[0][1] == expected_args
+
+        expected_args["run_id"] = "9d3b14f7-de91-40b6-aeef-e887e2c7673e"
+        adapter = OpenLineageAdapter()
+        adapter.complete_task(**expected_args)
+        assert mock_emit.assert_called_once
 
     @mock.patch(
         "airflow.providers.openlineage.plugins.listener.OpenLineageListener._execute", new=regular_call
@@ -1500,12 +1479,10 @@ class TestOpenLineageListenerAirflow3:
     @mock.patch("airflow.providers.openlineage.plugins.listener.is_operator_disabled")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_run_facet")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_user_provided_run_facets")
-    @mock.patch("airflow.providers.openlineage.plugins.listener.get_job_name")
     def test_listener_on_task_instance_running_do_not_call_adapter_when_disabled_operator(
-        self, mock_get_job_name, mock_get_user_provided_run_facets, mock_get_airflow_run_facet, mock_disabled
+        self, mock_get_user_provided_run_facets, mock_get_airflow_run_facet, mock_disabled
     ):
         listener, task_instance = self._create_listener_and_task_instance()
-        mock_get_job_name.return_value = "job_name"
         mock_get_user_provided_run_facets.return_value = {"custom_facet": 2}
         mock_get_airflow_run_facet.return_value = {"airflow_run_facet": 3}
         mock_disabled.return_value = True
@@ -1519,9 +1496,8 @@ class TestOpenLineageListenerAirflow3:
 
     @mock.patch("airflow.providers.openlineage.plugins.listener.is_operator_disabled")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_user_provided_run_facets")
-    @mock.patch("airflow.providers.openlineage.plugins.listener.get_job_name")
     def test_listener_on_task_instance_failed_do_not_call_adapter_when_disabled_operator(
-        self, mock_get_job_name, mock_get_user_provided_run_facets, mock_disabled
+        self, mock_get_user_provided_run_facets, mock_disabled
     ):
         listener, task_instance = self._create_listener_and_task_instance()
         mock_get_user_provided_run_facets.return_value = {"custom_facet": 2}
@@ -1540,9 +1516,8 @@ class TestOpenLineageListenerAirflow3:
 
     @mock.patch("airflow.providers.openlineage.plugins.listener.is_operator_disabled")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_user_provided_run_facets")
-    @mock.patch("airflow.providers.openlineage.plugins.listener.get_job_name")
     def test_listener_on_task_instance_success_do_not_call_adapter_when_disabled_operator(
-        self, mock_get_job_name, mock_get_user_provided_run_facets, mock_disabled
+        self, mock_get_user_provided_run_facets, mock_disabled
     ):
         listener, task_instance = self._create_listener_and_task_instance()
         mock_get_user_provided_run_facets.return_value = {"custom_facet": 2}
@@ -1574,6 +1549,7 @@ class TestOpenLineageListenerAirflow3:
         mock_executor.assert_called_once_with(max_workers=expected, initializer=mock.ANY)
         mock_executor.return_value.submit.assert_called_once()
 
+    @pytest.mark.db_test
     @pytest.mark.parametrize(
         ("method", "dag_run_state"),
         [
